==> codequery_0.21.1+dfsg1.orig.tar.xz: codequery-0.21.1/makedb/swver.h <==

/*
 * CodeQuery
 * Copyright (C) 2013-2017 ruben2020 https://github.com/ruben2020/
 * 
 * This Source Code Form is subject to the terms of the Mozilla Public
 * License, v. 2.0. If a copy of the MPL was not distributed with this
 * file, You can obtain one at http://mozilla.org/MPL/2.0/.
 *
 */


#ifndef SWVER_H_CQ
#define SWVER_H_CQ

#define CODEQUERY_SW_VERSION      "CodeQuery 0.21.1"
#define CODEQUERY_SW_VERSION_WEBSITE      "<p>"\
	CODEQUERY_SW_VERSION \
	"</p>"\
	"<p><a href=\"http://ruben2020.github.io/codequery/\">Official Website</a></p>"\
	"<p><a href=\"https://github.com/ruben2020/codequery\">GitHub Page</a></p>"


#define CODEQUERY_SW_LICENSE  \
"Copyright (C) 2013-2017 ruben2020 https://github.com/ruben2020/\n\n" \
"Website: https://github.com/ruben2020/codequery\n\n" \
"The Source Code Form and the Executable Form of this software\n" \
"are subject to the terms of the Mozilla Public License, v. 2.0.\n" \
"If a copy of the MPL was not distributed with this software,\n" \
"You can obtain one at http://mozilla.org/MPL/2.0/.\n\n" \
"The Source Code Form of this software can be obtained from:\n" \
"https://github.com/ruben2020/codequery\n\n" \
"This software is distributed in the hope that it will be useful,\n" \
"but WITHOUT ANY WARRANTY; without even the implied warranty of\n" \
"MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the\n" \
"Mozilla Public License, v. 2.0 for more details.\n\n" \

#define CODEQUERY_SW_LICENSE_PARA  \
"Copyright (C) 2013-2017 ruben2020 https://github.com/ruben2020/\n\n" \
"Website: https://github.com/ruben2020/codequery\n\n" \
"The Source Code Form and the Executable Form of this software " \
"are subject to the terms of the Mozilla Public License, v. 2.0. " \
"If a copy of the MPL was not distributed with this software, " \
"You can obtain one at http://mozilla.org/MPL/2.0/.\n\n" \
"The Source Code Form of this software can be obtained from: " \
"https://github.com/ruben2020/codequery\n\n" \
"This software is distributed in the hope that it will be useful, " \
"but WITHOUT ANY WARRANTY; without even the implied warranty of " \
"MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the " \
"Mozilla Public License, v. 2.0 for more details.\n\n" \

#define CODEQUERY_SW_LICENSE_PARA_LINK  \
"<p>Copyright (C) 2013-2017 <a href=\"https://github.com/ruben2020/\">ruben2020</a></p>\n\n" \
"<p>The Source Code Form and the Executable Form of this software " \
"are subject to the terms of the Mozilla Public License, v. 2.0. " \
"If a copy of the MPL was not distributed with this software, " \
"You can obtain one at <a href=\"http://mozilla.org/MPL/2.0/\">http://mozilla.org/MPL/2.0/</a>.</p>\n\n" \
"<p>The Source Code Form of this software can be obtained from: " \
"<a href=\"https://github.com/ruben2020/codequery\">https://github.com/ruben2020/codequery</a></p>\n\n" \
"<p>This software is distributed in the hope that it will be useful, " \
"but WITHOUT ANY WARRANTY; without even the implied warranty of " \
"MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the " \
"Mozilla Public License, v. 2.0 for more details.</p>\n\n" \


/**
 * \mainpage CodeQuery Documentation
 *
 * GitHub: https://github.com/ruben2020/codequery
 * 
 * Downloads: http://sourceforge.net/projects/codequery/files/
 * 
 * This is a tool to index, then query or search C, C++, Java, Python, Ruby, Go and Javascript source code.
 * It builds upon the databases of cscope and Exuberant ctags.
 * The databases of cscope and ctags would be processed by the cqmakedb tool to
 * generate the CodeQuery database file.
 * The CodeQuery database file can be viewed and queried using the codequery GUI tool.
 *
 * This contains only the Doxygen documentation of the source code.
 * For the rest, please see the Github page above.
 */

#endif // SWVER_H_CQ

==> codequery_0.24.0+dfsg1.orig.tar.xz: codequery-0.24.0/makedb/swver.h <==

/*
 * CodeQuery
 * Copyright (C) 2013-2017 ruben2020 https://github.com/ruben2020/
 * 
 * This Source Code Form is subject to the terms of the Mozilla Public
 * License, v. 2.0. If a copy of the MPL was not distributed with this
 * file, You can obtain one at https://www.mozilla.org/en-US/MPL/2.0/.
 *
 */


#ifndef SWVER_H_CQ
#define SWVER_H_CQ

#define CODEQUERY_SW_VERSION      "CodeQuery 0.24.0"
#define CODEQUERY_SW_VERSION_WEBSITE      "<p>"\
	CODEQUERY_SW_VERSION \
	"</p>"\
	"<p><a href=\"http://ruben2020.github.io/codequery/\">Official Website</a></p>"\
	"<p><a href=\"https://github.com/ruben2020/codequery\">GitHub Page</a></p>"


#define CODEQUERY_SW_LICENSE  \
"Copyright (C) 2013-2021 ruben2020 https://github.com/ruben2020/\n\n" \
"Website: https://github.com/ruben2020/codequery\n\n" \
"The Source Code Form and the Executable Form of this software\n" \
"are subject to the terms of the Mozilla Public License, v. 2.0.\n" \
"If a copy of the MPL was not distributed with this software,\n" \
"You can obtain one at https://www.mozilla.org/en-US/MPL/2.0/.\n\n" \
"The Source Code Form of this software can be obtained from:\n" \
"https://github.com/ruben2020/codequery\n\n" \
"This software is distributed in the hope that it will be useful,\n" \
"but WITHOUT ANY WARRANTY; without even the implied warranty of\n" \
"MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the\n" \
"Mozilla Public License, v. 2.0 for more details.\n\n" \

#define CODEQUERY_SW_LICENSE_PARA  \
"Copyright (C) 2013-2021 ruben2020 https://github.com/ruben2020/\n\n" \
"Website: https://github.com/ruben2020/codequery\n\n" \
"The Source Code Form and the Executable Form of this software " \
"are subject to the terms of the Mozilla Public License, v. 2.0. " \
"If a copy of the MPL was not distributed with this software, " \
"You can obtain one at https://www.mozilla.org/en-US/MPL/2.0/.\n\n" \
"The Source Code Form of this software can be obtained from: " \
"https://github.com/ruben2020/codequery\n\n" \
"This software is distributed in the hope that it will be useful, " \
"but WITHOUT ANY WARRANTY; without even the implied warranty of " \
"MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the " \
"Mozilla Public License, v. 2.0 for more details.\n\n" \

#define CODEQUERY_SW_LICENSE_PARA_LINK  \
"<p>Copyright (C) 2013-2021 <a href=\"https://github.com/ruben2020/\">ruben2020</a></p>\n\n" \
"<p>The Source Code Form and the Executable Form of this software " \
"are subject to the terms of the Mozilla Public License, v. 2.0. " \
"If a copy of the MPL was not distributed with this software, " \
"You can obtain one at <a href=\"https://www.mozilla.org/en-US/MPL/2.0/\">https://www.mozilla.org/en-US/MPL/2.0/</a>.</p>\n\n" \
"<p>The Source Code Form of this software can be obtained from: " \
"<a href=\"https://github.com/ruben2020/codequery\">https://github.com/ruben2020/codequery</a></p>\n\n" \
"<p>This software is distributed in the hope that it will be useful, " \
"but WITHOUT ANY WARRANTY; without even the implied warranty of " \
"MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the " \
"Mozilla Public License, v. 2.0 for more details.</p>\n\n" \


/**
 * \mainpage CodeQuery Documentation
 *
 * GitHub: https://github.com/ruben2020/codequery
 * 
 * Downloads: http://sourceforge.net/projects/codequery/files/
 * 
 * This is a tool to index, then query or search C, C++, Java, Python, Ruby, Go and Javascript source code.
 * It builds upon the databases of cscope and Exuberant ctags.
 * The databases of cscope and ctags would be processed by the cqmakedb tool to
 * generate the CodeQuery database file.
 * The CodeQuery database file can be viewed and queried using the codequery GUI tool.
 *
 * This contains only the Doxygen documentation of the source code.
 * For the rest, please see the Github page above.
 */

#endif // SWVER_H_CQ
